# E-TRAINEE_M4_UTILS
A package containing utilities for classification exercises in module 4 of [e-trainee](https://3dgeo-heidelberg.github.io/etrainee/module4/module4.html).

Includes tools for preprocessing gdal-compatible rasters and ingesting them into the classification workflows,
combining classified tiles after deep learning, visualising the process and exporting results. Also included are
Spectral Angle Mapper (SAM) and Spectral Information Divergence (SID) classifiers (implementation based on pysptools).